@@ -1,7 +1,7 @@
 #
 # This file is part of App-Cme
 #
-# This software is Copyright (c) 2016 by Dominique Dumont.
+# This software is Copyright (c) 2017 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -10,7 +10,7 @@
 # ABSTRACT: Dump the configuration of an application
 
 package App::Cme::Command::dump ;
-$App::Cme::Command::dump::VERSION = '1.015';
+$App::Cme::Command::dump::VERSION = '1.017';
 use strict;
 use warnings;
 use 5.10.1;
@@ -25,12 +25,14 @@ use JSON;
 use Data::Dumper;
 
 sub validate_args {
-    shift->process_args(@_);
+    my ($self, $opt, $args) = @_;
+    $opt->{quiet} = 1; # don't want to mess up yaml output
+    $self->process_args($opt,$args);
 }
 
 sub opt_spec {
     my ( $class, $app ) = @_;
-    return ( 
+    return (
         [
             "dumptype=s" => "Dump all values (full) or only customized values",
             {
@@ -45,6 +47,7 @@ sub opt_spec {
                 default => 'yaml'
             },
         ],
+        [ "quiet!"             => "Suppress progress messages" ],
         $class->cme_global_options,
     );
 }
@@ -100,7 +103,7 @@ App::Cme::Command::dump - Dump the configuration of an application
 
 =head1 VERSION
 
-version 1.015
+version 1.017
 
 =head1 SYNOPSIS
 
@@ -140,7 +143,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Dominique Dumont.
+This software is Copyright (c) 2017 by Dominique Dumont.
 
 This is free software, licensed under:
 
