@@ -1,7 +1,7 @@
 #
 # This file is part of App-Cme
 #
-# This software is Copyright (c) 2016 by Dominique Dumont.
+# This software is Copyright (c) 2017 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -10,7 +10,7 @@
 # ABSTRACT: Edit the configuration of an application with a shell
 
 package App::Cme::Command::shell ;
-$App::Cme::Command::shell::VERSION = '1.015';
+$App::Cme::Command::shell::VERSION = '1.017';
 use strict;
 use warnings;
 use 5.10.1;
@@ -28,6 +28,8 @@ sub opt_spec {
     my ( $class, $app ) = @_;
     return ( 
         [ "open-item=s" => "open a specific item of the configuration" ],
+        [ "quiet!"      => "Suppress progress messages" ],
+        [ "bare!"       => "run bare terminal UI"],
         $class->cme_global_options,
     );
 }
@@ -48,20 +50,16 @@ sub execute {
 
     my ($model, $inst, $root) = $self->init_cme($opt,$args);
 
-    eval { require Term::ReadLine; };
-    my $has_term_readline = $@ ? 0 : 1;
-
     $root->deep_check;
 
-    if ($has_term_readline) {
-        require Config::Model::TermUI;
-        $self->run_shell_ui('Config::Model::TermUI', $inst) ;
-    }
-    else {
-        warn "You should install Term::ReadLine for a more friendly user interface\n";
+    if ($opt->{bare})  {
         require Config::Model::SimpleUI;
         $self->run_shell_ui('Config::Model::SimpleUI', $inst) ;
     }
+    else {
+        require Config::Model::TermUI;
+        $self->run_shell_ui('Config::Model::TermUI', $inst) ;
+    }
 }
 
 1;
@@ -78,7 +76,7 @@ App::Cme::Command::shell - Edit the configuration of an application with a shell
 
 =head1 VERSION
 
-version 1.015
+version 1.017
 
 =head1 SYNOPSIS
 
@@ -102,6 +100,14 @@ See L<cme/"Global Options">.
 
 Open a specific item of the configuration when opening the editor
 
+=item -quiet
+
+Suppress porgress message
+
+=item -bare
+
+Use Term UI without auto-completion or font enhancements.
+
 =back
 
 =head1 SEE ALSO
@@ -114,7 +120,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Dominique Dumont.
+This software is Copyright (c) 2017 by Dominique Dumont.
 
 This is free software, licensed under:
 
